@@ -3,7 +3,6 @@ import os
 import pydub 
 from pydub import AudioSegment
 
-import numpy as np
 cwd = os.getcwd()
 import wave
 import contextlib
@@ -11,10 +10,10 @@ import contextlib
 
 
 def upsample(cmnd):
-    print "upsampling to 48000 Hz"
+    print ("upsampling to 48000 Hz")
     print(cwd)
     text_to_file = cmnd[1]
-    CHUNKSIZE = 1024 # fixed chunk size
+    
     input_name= cwd +'/'+ text_to_file
     print(input_name)
     # # initialize portaudio
@@ -33,7 +32,7 @@ def upsample(cmnd):
     swidth = 2
     spf = wave.open(input_name, 'rb')
     RATE=spf.getframerate()
-    print " Current frame rate is "
+    print( " Current frame rate is ")
     print(RATE)
     signal = spf.readframes(-1)
     if (RATE == 48000):
@@ -49,7 +48,7 @@ def upsample(cmnd):
 
 def getrate(cmnd):
     
-    print "Getting frame rate"
+    print ("Getting frame rate")
     print(cwd)
     text_to_file = cmnd[1]
     input_name= cwd +'/'+ text_to_file
@@ -58,11 +57,11 @@ def getrate(cmnd):
     CHANNELS = 2
     spf = wave.open(input_name, 'rb')
     RATE=spf.getframerate()
-    print " Current frame rate is "
+    print (" Current frame rate is ")
     print(RATE)
 
 def getduration(cmnd):
-    print "The file duration of"
+    print ("The file duration of")
     text_to_file = cmnd[1]
     input_name= cwd +'/'+ text_to_file
     print(input_name)
@@ -92,7 +91,7 @@ def returnduration(input_name):
     return -1
 
 def getsize(cmnd):
-    print "The file size of"
+    print ("The file size of")
     text_to_file = cmnd[1]
     input_name= cwd +'/'+ text_to_file
     print(input_name)
@@ -104,14 +103,14 @@ def getsize(cmnd):
         siz= siz/1024
         cu = cu + 1
     if(cu == 1):
-        print siz , " KB"
+        print (siz , " KB")
     elif(cu ==2):
-        print siz , " MB"
+        print (siz , " MB")
     elif(cu ==3):
-        print siz , " GB"
+        print (siz , " GB")
 
 def getlength(cmnd):
-    print "The track length"
+    print ("The track length")
     text_to_file = cmnd[1]
     input_name= cwd +'/'+ text_to_file
     print(input_name)
@@ -129,7 +128,7 @@ def getlength(cmnd):
 
 def downsample(cmnd):
     
-    print "upsampling to 8000 Hz"
+    print ("upsampling to 8000 Hz")
     print(cwd)
     text_to_file = cmnd[1]
     input_name= cwd +'/'+ text_to_file
@@ -139,7 +138,7 @@ def downsample(cmnd):
     swidth = 2
     spf = wave.open(input_name, 'rb')
     RATE=spf.getframerate()
-    print " Current frame rate is "
+    print( " Current frame rate is ")
     print(RATE)
     signal = spf.readframes(-1)
     if (RATE == 8000):
